"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Markdown = void 0;

var _react = _interopRequireDefault(require("react"));

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _reactMarkdown = _interopRequireDefault(require("react-markdown"));

var _rehypeRaw = _interopRequireDefault(require("rehype-raw"));

var _remarkGfm = _interopRequireDefault(require("remark-gfm"));

var _components = require("@looker/components");

var _CodeDisplay = require("../CodeDisplay");

var _utils = require("./utils");

var _TableCell = require("./TableCell");

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Markdown = _ref => {
  var {
    source,
    pattern = '',
    transformLinkUri,
    linkClickHandler,
    paragraphOverride
  } = _ref;

  var findAnchor = ele => {
    if (ele.tagName === 'A') return ele;

    if (ele.parentElement) {
      return findAnchor(ele.parentElement);
    }

    return undefined;
  };

  var handleClick = e => {
    e.preventDefault();

    if (linkClickHandler) {
      var a = findAnchor(e.target);

      if (a) {
        linkClickHandler(a.pathname, a.href);
      }
    }
  };

  var heading = _ref2 => {
    var {
      level,
      children
    } = _ref2;
    return _react.default.createElement(_common.MDHeading, {
      as: "h".concat(level)
    }, children);
  };

  var paragraph = _ref3 => {
    var {
      children
    } = _ref3;
    return _react.default.createElement(_common.MDParagraph, null, children);
  };

  var code = _ref4 => {
    var {
      inline,
      children
    } = _ref4;
    var {
      text,
      language
    } = (0, _utils.prepareCodeText)((children === null || children === void 0 ? void 0 : children.toString()) || '');
    var codeProps = {
      language: language,
      code: text,
      pattern: pattern,
      lineNumbers: false,
      inline: inline
    };
    return _react.default.createElement(_CodeDisplay.CodeDisplay, codeProps);
  };

  var components = {
    h1: heading,
    h2: heading,
    h3: heading,
    h4: heading,
    h5: heading,
    h6: heading,
    p: paragraphOverride || paragraph,
    code: code,
    a: _components.Link,
    ul: _common.MDList,
    ol: _common.MDList,
    link: _components.Link,
    li: _common.MDListItem,
    table: _common.MDTable,
    thead: _components.TableHead,
    tbody: _components.TableBody,
    tr: _components.TableRow,
    td: _TableCell.TableCell,
    th: _TableCell.TableCell
  };
  return _react.default.createElement(MarkdownWrapper, {
    onClick: handleClick
  }, _react.default.createElement(_reactMarkdown.default, {
    remarkPlugins: [_remarkGfm.default],
    rehypePlugins: [_rehypeRaw.default],
    transformLinkUri: transformLinkUri,
    components: components
  }, (0, _utils.qualifyMarkdownText)(source, pattern)));
};

exports.Markdown = Markdown;

var MarkdownWrapper = _styledComponents.default.div.withConfig({
  displayName: "Markdown__MarkdownWrapper",
  componentId: "sc-11uco0h-0"
})(["& > ul{padding-left:20px;list-style:disc outside;}& > ol{padding-left:20px;list-style:decimal outside;}"]);
//# sourceMappingURL=Markdown.js.map