import React from 'react';
import styled from 'styled-components';
import ReactMarkdown from 'react-markdown';
import rehypeRaw from 'rehype-raw';
import gfm from 'remark-gfm';
import { TableHead, TableBody, TableRow, Link } from '@looker/components';
import { CodeDisplay } from '../CodeDisplay';
import { qualifyMarkdownText, prepareCodeText } from './utils';
import { TableCell } from './TableCell';
import { MDHeading, MDList, MDListItem, MDParagraph, MDTable } from './common';
export var Markdown = _ref => {
  var {
    source,
    pattern = '',
    transformLinkUri,
    linkClickHandler,
    paragraphOverride
  } = _ref;

  var findAnchor = ele => {
    if (ele.tagName === 'A') return ele;

    if (ele.parentElement) {
      return findAnchor(ele.parentElement);
    }

    return undefined;
  };

  var handleClick = e => {
    e.preventDefault();

    if (linkClickHandler) {
      var a = findAnchor(e.target);

      if (a) {
        linkClickHandler(a.pathname, a.href);
      }
    }
  };

  var heading = _ref2 => {
    var {
      level,
      children
    } = _ref2;
    return React.createElement(MDHeading, {
      as: "h".concat(level)
    }, children);
  };

  var paragraph = _ref3 => {
    var {
      children
    } = _ref3;
    return React.createElement(MDParagraph, null, children);
  };

  var code = _ref4 => {
    var {
      inline,
      children
    } = _ref4;
    var {
      text,
      language
    } = prepareCodeText((children === null || children === void 0 ? void 0 : children.toString()) || '');
    var codeProps = {
      language: language,
      code: text,
      pattern: pattern,
      lineNumbers: false,
      inline: inline
    };
    return React.createElement(CodeDisplay, codeProps);
  };

  var components = {
    h1: heading,
    h2: heading,
    h3: heading,
    h4: heading,
    h5: heading,
    h6: heading,
    p: paragraphOverride || paragraph,
    code: code,
    a: Link,
    ul: MDList,
    ol: MDList,
    link: Link,
    li: MDListItem,
    table: MDTable,
    thead: TableHead,
    tbody: TableBody,
    tr: TableRow,
    td: TableCell,
    th: TableCell
  };
  return React.createElement(MarkdownWrapper, {
    onClick: handleClick
  }, React.createElement(ReactMarkdown, {
    remarkPlugins: [gfm],
    rehypePlugins: [rehypeRaw],
    transformLinkUri: transformLinkUri,
    components: components
  }, qualifyMarkdownText(source, pattern)));
};
var MarkdownWrapper = styled.div.withConfig({
  displayName: "Markdown__MarkdownWrapper",
  componentId: "sc-11uco0h-0"
})(["& > ul{padding-left:20px;list-style:disc outside;}& > ol{padding-left:20px;list-style:decimal outside;}"]);
//# sourceMappingURL=Markdown.js.map