import { instanceOfPrismLanguage } from '../utils';
export var regReplaceAll = (content, pattern, replacementFunc) => {
  var target = new RegExp(pattern, 'gi');
  return content.replace(target, replacementFunc);
};
export var addMarkTags = (content, searchPattern) => {
  var markedContent;

  try {
    var replacement = match => "<mark>".concat(match, "</mark>");

    markedContent = regReplaceAll(content, searchPattern, replacement);
  } catch (e) {
    markedContent = content;
  }

  return markedContent;
};
export var removeMarkTags = markedText => {
  return markedText.replace(/<\/?mark>/g, '');
};
export var addCodeLanguageTags = content => {
  var languageTaggedContent;

  try {
    var searchPattern = /```([A-Za-z]+)$/gm;
    var match = searchPattern.exec(content);
    var language = match && match[1];

    var replacement = () => "```\n<".concat(language, "/>");

    languageTaggedContent = content.replace(searchPattern, replacement);
  } catch (e) {
    languageTaggedContent = content;
  }

  return languageTaggedContent;
};
export var removeCodeLanguageTags = content => {
  var untaggedContent;

  try {
    var replacement = () => '';

    var searchPattern = /<(.*)\/>$/gm;
    var match = searchPattern.exec(content);
    var language = match && match[1];

    if (language && instanceOfPrismLanguage(language)) {
      untaggedContent = regReplaceAll(content, '<' + language + '/>\n', replacement);
    } else {
      untaggedContent = content;
    }
  } catch (e) {
    untaggedContent = content;
  }

  return untaggedContent;
};
export var getCodeLanguageFromTaggedText = content => {
  var searchPattern = /<(.*)\/>$/gm;
  var match = searchPattern.exec(content);
  return match ? match[1] : 'markup';
};
export var prepareCodeText = content => {
  var text = content;
  var language = getCodeLanguageFromTaggedText(text);
  text = removeCodeLanguageTags(text);
  text = removeMarkTags(text);
  text = text.trim();
  return {
    text,
    language
  };
};
export var qualifyMarkdownText = (content, pattern) => {
  var qualifiedContent;

  if (pattern !== '') {
    qualifiedContent = addMarkTags(content, pattern);
  }

  qualifiedContent = addCodeLanguageTags(qualifiedContent || content);
  return qualifiedContent;
};
//# sourceMappingURL=utils.js.map